==> php-residence_0.2.4.tar.gz: php-residence/storia_soldi.php <==
<html>
<header>
<title> Storia soldi </title>
</header>
<body bgcolor=#ffffff>

<?php

##################################################################################
#    PHP-RESIDENCE
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################

$pag = "storia_soldi.php";

include ("dati/connessione_db.php");
include ("includes/funzioni.php");
$tablenometariffe = ntariffe . $anno;
$tableprenota = prenota .$anno;
$tableperiodi = periodi . $anno;
$tablecosti = costi . $anno;
$tablesoldi = soldi . $anno;
$stile_soldi = stile_soldi();

if (!$cerca_prenota) {
echo "<table width=\"100%\"><tr><td align=\"left\">
<form method=\"post\" action=\"storia_soldi.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"senza_colori\" value=\"$senza_colori\">
<input type=\"submit\" name=\"cerca_prenota\" value=\"".mex("Vedi le modifiche",$pag)."\">
 ".mex("dal",$pag)." <select name=\"cerca_inizioperiodo\">
<option value=\"\" selected>----</option>";
$anno_prec = $anno - 1;
$anno_succ = $anno + 1;
$numgiorno = 1;
do {
$data_select = date("M d, " , mktime(0,0,0,1,$numgiorno,$anno));
$data_select_vedi = date("d-m" , mktime(0,0,0,1,$numgiorno,$anno));
$numgiorno++;
$annocreato = date("Y" , mktime(0,0,0,1,$numgiorno,$anno));
echo "<option value=\"$data_select\">$data_select_vedi</option>";
} while ($annocreato == $anno);
echo "</select>
<select name=\"cerca_anno_inizioperiodo\">
<option value=\"$anno_prec\">$anno_prec</option>
<option value=\"$anno\" selected>$anno</option>
<option value=\"$anno_succ\">$anno_succ</option>
</select>
 ".mex("al",$pag)." <select name=\"cerca_fineperiodo\">
<option value=\"\" selected>----</option>";
$numgiorno = 1;
do {
$data_select = date("M d, " , mktime(0,0,0,1,$numgiorno,$anno));
$data_select_vedi = date("d-m" , mktime(0,0,0,1,$numgiorno,$anno));
$numgiorno++;
$annocreato = date("Y" , mktime(0,0,0,1,$numgiorno,$anno));
echo "<option value=\"$data_select\">$data_select_vedi</option>";
} while ($annocreato == $anno);
echo "</select>
<select name=\"cerca_anno_fineperiodo\">
<option value=\"$anno_prec\">$anno_prec</option>
<option value=\"$anno\" selected>$anno</option>
<option value=\"$anno_succ\">$anno_succ</option>
</select></form></td>
<td align=\"right\">
<form method=\"post\" action=\"storia_soldi.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">";
if (!$senza_colori) {
echo "<input type=\"hidden\" name=\"senza_colori\" value=\"SI\">
<input type=\"submit\" name=\"cambia_colori\" value=\"".mex("Senza colori",$pag)."\">";
} # fine if (!$senza_colori)
else echo "<input type=\"submit\" name=\"cambia_colori\" value=\"".mex("Con colori",$pag)."\">";
echo "</form></td></tr></table>";
} # fine if (!$cerca_prenota)

else {
if ($cerca_inizioperiodo) {
$cerca_inizioperiodo .= $cerca_anno_inizioperiodo;
$periodo_query = " and data_inserimento >= '$cerca_inizioperiodo'";
$frase_periodo = " ".mex("dal",$pag)." $cerca_inizioperiodo";
} # fine if ($cerca_inizioperiodo)
if ($cerca_fineperiodo) {
$cerca_fineperiodo .= $cerca_anno_fineperiodo;
$periodo_query .= " and data_inserimento <= '$cerca_fineperiodo'";
$frase_periodo .= " ".mex("fino al",$pag)." $cerca_fineperiodo";
} # fine if ($cerca_fineperiodo)
} # fine else if (!$cerca_prenota)

$saldo_prenota_TOT = 0;
if (!$senza_colori) $colore = "#b9ccd4";
else $colore = "#ffffff";

echo "<center><font size=+2><b>".mex("Storia delle entate e uscite delle prenotazioni inserite nel",$pag)." $anno$frase_periodo</b></font></center>
<br><table width=200 border=3 cellspacing=2 cellpadding=4 align=\"center\" bgcolor=\"$colore\">
<tr><td align=\"center\" colspan=3>".mex("Dati della prenotazione",$pag)."</td>
<td align=\"center\" rowspan=2>".mex("Pagato prima",$pag)."</td>
<td align=\"center\" rowspan=2>".mex("Pagato dopo",$pag)."</td>
<td align=\"center\" rowspan=2>".mex("Saldo",$pag)."</td>
<td align=\"center\" rowspan=2>".mex("Data_della modifica",$pag)."</td></tr>
<tr><td>".mex("Cognome_cliente",$pag)."</td><td>".mex("Data_inizale",$pag)."</td><td>".mex("Data_finale",$pag)."</td></tr>";

$storia_soldi_prenota = pg_exec("select * from $tablesoldi where saldo_prenota != ''$periodo_query order by idsoldi");
$num_storia_soldi_prenota = pg_numrows($storia_soldi_prenota);

for ($num1 = 0 ; $num1 < $num_storia_soldi_prenota ; $num1 = $num1 + 1) {
$data_inserimento = pg_result($storia_soldi_prenota,$num1,data_inserimento);
$data_inserimento = substr($data_inserimento, 4, 20);
$string = substr($data_inserimento, 6, 9);
$data_inserimento = ereg_replace($string,"",$data_inserimento);
$motivazione = pg_result($storia_soldi_prenota,$num1,motivazione);
$motivazione = explode(";",$motivazione);
$cognome = pg_exec("select * from clienti where idclienti = ".$motivazione[0]);
$cognome = pg_result($cognome,0,cognome);
$data_inizio = pg_exec("select * from $tableperiodi where idperiodi = ".$motivazione[1]);
$data_inizio = pg_result($data_inizio,0,datainizio);
$data_fine = pg_exec("select * from $tableperiodi where idperiodi = ".$motivazione[2]);
$data_fine = pg_result($data_fine,0,datafine);
$soldi_prima = pg_result($storia_soldi_prenota,$num1,soldi_prima);
$saldo_prenota = pg_result($storia_soldi_prenota,$num1,saldo_prenota);
$soldi_dopo = $soldi_prima + $saldo_prenota;
$saldo_prenota_TOT = $saldo_prenota_TOT + $saldo_prenota;

$soldi_prima_p = punti_in_num($soldi_prima,$stile_soldi);
$soldi_dopo_p = punti_in_num($soldi_dopo,$stile_soldi);
$saldo_prenota_p = punti_in_num($saldo_prenota,$stile_soldi);

echo "<tr><td align=\"center\">$cognome</td>
<td align=\"center\">$data_inizio</td>
<td align=\"center\">$data_fine</td>
<td align=\"center\">$soldi_prima_p</td>
<td align=\"center\">$soldi_dopo_p</td>
<td align=\"center\">$saldo_prenota_p</td>
<td align=\"center\"><font size=-1>$data_inserimento</font></td></tr>";

} # fine for $num1

$saldo_prenota_TOT_p = punti_in_num($saldo_prenota_TOT,$stile_soldi);
echo "<tr><td align=\"center\" colspan=5><b>".mex("TOTALE",$pag)."</b></td>
<td align=\"center\">$saldo_prenota_TOT_p</td>
<td align=\"center\">&nbsp;</td></tr>";

$costo_cassa = pg_exec("select * from $tablecosti where idcosti = 0");
$costo_cassa = pg_result($costo_cassa,0,val_costo);
if ($costo_cassa and !$cerca_prenota) {
$resto_tot = $saldo_prenota_TOT - $costo_cassa;
$costo_cassa_p = punti_in_num($costo_cassa,$stile_soldi);
$resto_tot_p = punti_in_num($resto_tot,$stile_soldi);
echo "<tr><td align=\"center\" colspan=\"5\"><b><i>".mex("Trasferito in cassa",$pag).":</i></b></td>
<td align=\"center\">$costo_cassa_p</td>";
echo "<td align=\"center\">&nbsp;</td></tr>
<tr><td align=\"center\" colspan=\"5\"><b><i>".mex("RESTO",$pag)."</i></b></td>
<td align=\"center\">$resto_tot_p</td>";
echo "<td align=\"center\">&nbsp;</td></tr>";
} # fine if ($costo_cassa and !$cerca_prenota)

echo "</table>

<br><center>
<form method=\"post\" action=\"visualizza_tabelle.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"tipo_tabella\" value=\"costi\">
<input type=\"submit\" name=\"torna\" value=\"".mex("Torna indietro",$pag)."\">
</form></center>";


?>


</body>
</html>

==> php-residence_0.3.tar.gz: php-residence/storia_soldi.php <==
<html>
<header>
<title> Storia soldi </title>
</header>
<body bgcolor=#ffffff>

<?php

##################################################################################
#    PHP-RESIDENCE
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################

$pag = "storia_soldi.php";

include("./dati/dati_connessione.php");
include("./includes/funzioni_$PHPR_DB_TYPE.php");
connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
include ("./includes/funzioni.php");
$tablenometariffe = ntariffe . $anno;
$tableprenota = prenota .$anno;
$tableperiodi = periodi . $anno;
$tablecosti = costi . $anno;
$tablesoldi = soldi . $anno;
$stile_soldi = stile_soldi();
$stile_data = stile_data();

if (!$cerca_prenota) {
echo "<table width=\"100%\"><tr><td align=\"left\">
<form method=\"post\" action=\"storia_soldi.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"senza_colori\" value=\"$senza_colori\">
<input type=\"submit\" name=\"cerca_prenota\" value=\"".mex("Vedi le modifiche",$pag)."\">
 ".mex("dal",$pag)." <select name=\"cerca_inizioperiodo\">
<option value=\"\" selected>----</option>";
$anno_prec = $anno - 1;
$anno_succ = $anno + 1;
$numgiorno = 1;
do {
$data_select = date("-m-d " , mktime(0,0,0,1,$numgiorno,$anno));
$data_select_vedi = date("d-m" , mktime(0,0,0,1,$numgiorno,$anno));
$numgiorno++;
$annocreato = date("Y" , mktime(0,0,0,1,$numgiorno,$anno));
echo "<option value=\"$data_select\">$data_select_vedi</option>";
} while ($annocreato == $anno);
echo "</select>
<select name=\"cerca_anno_inizioperiodo\">
<option value=\"$anno_prec\">$anno_prec</option>
<option value=\"$anno\" selected>$anno</option>
<option value=\"$anno_succ\">$anno_succ</option>
</select>
 ".mex("al",$pag)." <select name=\"cerca_fineperiodo\">
<option value=\"\" selected>----</option>";
$numgiorno = 1;
do {
$data_select = date("-m-d" , mktime(0,0,0,1,$numgiorno,$anno));
$data_select_vedi = date("d-m" , mktime(0,0,0,1,$numgiorno,$anno));
$numgiorno++;
$annocreato = date("Y" , mktime(0,0,0,1,$numgiorno,$anno));
echo "<option value=\"$data_select\">$data_select_vedi</option>";
} while ($annocreato == $anno);
echo "</select>
<select name=\"cerca_anno_fineperiodo\">
<option value=\"$anno_prec\">$anno_prec</option>
<option value=\"$anno\" selected>$anno</option>
<option value=\"$anno_succ\">$anno_succ</option>
</select></form></td>
<td align=\"right\">
<form method=\"post\" action=\"storia_soldi.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"pagina_prenota\" value=\"$pagina_prenota\">";
if (!$senza_colori) {
echo "<input type=\"hidden\" name=\"senza_colori\" value=\"SI\">
<input type=\"submit\" name=\"cambia_colori\" value=\"".mex("Senza colori",$pag)."\">";
} # fine if (!$senza_colori)
else echo "<input type=\"submit\" name=\"cambia_colori\" value=\"".mex("Con colori",$pag)."\">";
echo "</form></td></tr></table>";
} # fine if (!$cerca_prenota)

else {
if ($cerca_inizioperiodo) {
$cerca_inizioperiodo = $cerca_anno_inizioperiodo.$cerca_inizioperiodo;
$cerca_inizioperiodo_f = formatta_data($cerca_inizioperiodo,$stile_data);
$periodo_query = " and data_inserimento >= '$cerca_inizioperiodo'";
$frase_periodo = " ".mex("dal",$pag)." $cerca_inizioperiodo_f";
} # fine if ($cerca_inizioperiodo)
if ($cerca_fineperiodo) {
$cerca_fineperiodo = $cerca_anno_fineperiodo.$cerca_fineperiodo;
$cerca_fineperiodo_f = formatta_data($cerca_fineperiodo,$stile_data);
$periodo_query .= " and data_inserimento <= '$cerca_fineperiodo'";
$frase_periodo .= " ".mex("fino al",$pag)." $cerca_fineperiodo_f";
} # fine if ($cerca_fineperiodo)
} # fine else if (!$cerca_prenota)

$saldo_prenota_TOT = 0;
if (!$senza_colori) $colore = "#b9ccd4";
else $colore = "#ffffff";

echo "<center><font size=+2><b>".mex("Storia delle entate e uscite delle prenotazioni inserite nel",$pag)." $anno$frase_periodo</b></font></center><br>";

$storia_soldi_prenota = esegui_query("select * from $tablesoldi where saldo_prenota != ''$periodo_query order by idsoldi");
$num_storia_soldi_prenota = numlin_query($storia_soldi_prenota);

if (!$cerca_prenota) {
$num_vedi_in_tab = esegui_query("select valpersonalizza_num from personalizza where idpersonalizza = 'num_righe_tab_storia_soldi'");
$num_vedi_in_tab = risul_query($num_vedi_in_tab,0,valpersonalizza_num);
if ($num_storia_soldi_prenota > $num_vedi_in_tab) {
$num_pagine_prenota = ceil($num_storia_soldi_prenota/$num_vedi_in_tab);
$stringa_pagine = "<center><font size=\"-1\">".mex("pagine",$pag)."</font>:";
if (!$pagina_prenota) $pagina_prenota = $num_pagine_prenota;
for ($num1 = 1 ; $num1 <= $num_pagine_prenota ; $num1++) {
$stringa_pagine .= " ";
if ($num1 != $pagina_prenota) {
$stringa_pagine .= "<a href=\"./storia_soldi.php?anno=$anno&senza_colori=$senza_colori&pagina_prenota=$num1\">";
} # fine if ($num1 != $pagina_prenota)
else $stringa_pagine .= "<b>";
$stringa_pagine .= "$num1";
if ($num1 != $pagina_prenota) $stringa_pagine .= "</a>";
else $stringa_pagine .= "</b>";
} # fine for $num1
$stringa_pagine .= "</center>";
echo $stringa_pagine;
$stringa_puntini_tab = "<tr><td align=\"center\" colspan=\"7\">...</td></tr>";
} # fine if ($num_storia_soldi_prenota > $num_vedi_in_tab)
else $pagina_prenota = 1;
} # fine if (!$cerca_prenota)

echo "<table width=200 border=3 cellspacing=2 cellpadding=4 align=\"center\" bgcolor=\"$colore\">
<tr><td align=\"center\" colspan=3>".mex("Dati della prenotazione",$pag)."</td>
<td align=\"center\" rowspan=2>".mex("Pagato prima",$pag)."</td>
<td align=\"center\" rowspan=2>".mex("Pagato dopo",$pag)."</td>
<td align=\"center\" rowspan=2>".mex("Saldo",$pag)."</td>
<td align=\"center\" rowspan=2>".mex("Data_della modifica",$pag)."</td></tr>
<tr><td>".mex("Cognome_cliente",$pag)."</td><td>".mex("Data_inizale",$pag)."</td><td>".mex("Data_finale",$pag)."</td></tr>";

if (!$cerca_prenota and $num_storia_soldi_prenota > $num_vedi_in_tab and $pagina_prenota != 1) echo $stringa_puntini_tab;

for ($num1 = 0 ; $num1 < $num_storia_soldi_prenota ; $num1 = $num1 + 1) {
$data_inserimento = risul_query($storia_soldi_prenota,$num1,data_inserimento);
$data_inserimento = substr($data_inserimento, 0, 10);
$data_inserimento_f = formatta_data($data_inserimento,$stile_data);
#$string = substr($data_inserimento, 6, 9);
#$data_inserimento = ereg_replace($string,"",$data_inserimento);
$motivazione = risul_query($storia_soldi_prenota,$num1,motivazione);
$motivazione = explode(";",$motivazione);
$cognome = esegui_query("select * from clienti where idclienti = ".$motivazione[0]);
$cognome = risul_query($cognome,0,cognome);
$data_inizio = esegui_query("select * from $tableperiodi where idperiodi = ".$motivazione[1]);
$data_inizio = risul_query($data_inizio,0,datainizio);
$data_fine = esegui_query("select * from $tableperiodi where idperiodi = ".$motivazione[2]);
$data_fine = risul_query($data_fine,0,datafine);
$soldi_prima = risul_query($storia_soldi_prenota,$num1,soldi_prima);
$saldo_prenota = risul_query($storia_soldi_prenota,$num1,saldo_prenota);
$soldi_dopo = $soldi_prima + $saldo_prenota;
$saldo_prenota_TOT = $saldo_prenota_TOT + $saldo_prenota;

$soldi_prima_p = punti_in_num($soldi_prima,$stile_soldi);
$soldi_dopo_p = punti_in_num($soldi_dopo,$stile_soldi);
$saldo_prenota_p = punti_in_num($saldo_prenota,$stile_soldi);

if ($cerca_prenota or (($num1+1) > (($pagina_prenota - 1)*$num_vedi_in_tab) and ($num1+1) <= (($pagina_prenota)*$num_vedi_in_tab)) ) {

echo "<tr><td align=\"center\">$cognome</td>
<td align=\"center\">$data_inizio</td>
<td align=\"center\">$data_fine</td>
<td align=\"center\">$soldi_prima_p</td>
<td align=\"center\">$soldi_dopo_p</td>
<td align=\"center\">$saldo_prenota_p</td>
<td align=\"center\"><font size=-1>$data_inserimento_f</font></td></tr>";

} # fine if ($cerca_prenota or (...

} # fine for $num1

if (!$cerca_prenota and $num_storia_soldi_prenota > $num_vedi_in_tab and $pagina_prenota != $num_pagine_prenota) echo $stringa_puntini_tab;

$saldo_prenota_TOT_p = punti_in_num($saldo_prenota_TOT,$stile_soldi);
echo "<tr><td align=\"center\" colspan=5><b>".mex("TOTALE",$pag)."</b></td>
<td align=\"center\">$saldo_prenota_TOT_p</td>
<td align=\"center\">&nbsp;</td></tr>";

$costo_cassa = esegui_query("select * from $tablecosti where idcosti = 0");
$costo_cassa = risul_query($costo_cassa,0,val_costo);
if ($costo_cassa and !$cerca_prenota) {
$resto_tot = $saldo_prenota_TOT - $costo_cassa;
$costo_cassa_p = punti_in_num($costo_cassa,$stile_soldi);
$resto_tot_p = punti_in_num($resto_tot,$stile_soldi);
echo "<tr><td align=\"center\" colspan=\"5\"><b><i>".mex("Trasferito in cassa",$pag).":</i></b></td>
<td align=\"center\">$costo_cassa_p</td>";
echo "<td align=\"center\">&nbsp;</td></tr>
<tr><td align=\"center\" colspan=\"5\"><b><i>".mex("RESTO",$pag)."</i></b></td>
<td align=\"center\">$resto_tot_p</td>";
echo "<td align=\"center\">&nbsp;</td></tr>";
} # fine if ($costo_cassa and !$cerca_prenota)

echo "</table>
$stringa_pagine

<br><center>
<form method=\"post\" action=\"visualizza_tabelle.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"tipo_tabella\" value=\"costi\">
<input type=\"submit\" name=\"torna\" value=\"".mex("Torna indietro",$pag)."\">
</form></center>";


?>


</body>
</html>
